@@ -14,6 +14,9 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+#ifdef __clang__ // _LIBCPP_VERSION
+#define _LIBCPP_HARDENING_MODE _LIBCPP_HARDENING_MODE_NONE
+#endif
 #undef max
 #undef min
 //#define GIAC_VECTOR
@@ -21,6 +24,14 @@
 #ifndef _GIAC_FIRST_H_
 #define _GIAC_FIRST_H_
 
+#define INT_MAXSHIFT (sizeof(int)*8-1)
+#define INT_MAXSHIFTM1 (sizeof(int)*8-2)
+
+#if __cplusplus >= 201103L || (defined(_MSVC_LANG) && _MSVC_LANG >= 201103L)
+// post-c++11 functional headers changes, thanks to George Huebner
+#define CPP11
+#endif
+  
 // register is deprecated in c++17
 #define register 
 
@@ -44,6 +55,10 @@
 #endif
 //#include <stdint.h>
 
+#if defined __MINGW32__ && !defined __MINGW_H
+#define __MINGW_H
+#endif
+
 // mingw now defines x86_64
 #if (defined(__x86_64__) || defined(__arm64__)) && !defined __MINGW_H
 #define x86_64 1
@@ -74,6 +89,7 @@
 #define M_1_PI 0.31830988618379067
 #endif
 
+
 #ifdef HP39
 #include <time.h>
 #define M_E 2.7182818284590452
@@ -130,7 +146,7 @@ inline Bidon operator << (Bidon,const char *){return Bidon();}
 #define COUT Bidon(0) //std::cout
 #define CERR Bidon(0) //std::cout
 typedef unsigned pid_t;
-double lgamma(double);
+extern "C" double lgamma(double);
 #else // FXCG
 
 #ifdef NSPIRE
@@ -194,6 +210,14 @@ int my_sprintf(char * s, const char * format, ...);
 #ifdef GIAC_HAS_STO_38
 //#define WITH_MYOSTREAM
 #endif
+#ifdef TICE
+#if 0 // if we find out that the OS sprintf is faster than nanoprintf, use it instead
+#include <ti/sprintf.h>
+#else
+// fallback
+#define boot_sprintf sprintf
+#endif
+#endif
 
 #ifdef WITH_MYOSTREAM
 #include "myostream.h"
